@@ -5,7 +5,9 @@ class SchemaKeyword(Enum):
     REQUIRED = "required"
     TITLE = "title"
     CONTAINS = "contains"
+    EXAMPLES = "examples"
     ITEMS = "items"
+    PREFIX_ITEMS = "prefixItems"
     UNIQUE_ITEMS = "uniqueItems"
     ADDITIONAL_ITEMS = "additionalItems"
     MAX_ITEMS = "maxItems"
